pub trait TileWriter:
DynClone
+ Send
+ Sync {
// Required methods
fn compression(&self) -> Compression;
fn exists<'life0, 'life1, 'async_trait>(
&'life0 self,
xyz: &'life1 Xyz,
) -> Pin<Box<dyn Future<Output = bool> + Send + 'async_trait>>
where Self: 'async_trait,
'life0: 'async_trait,
'life1: 'async_trait;
fn put_tile<'life0, 'life1, 'async_trait>(
&'life0 self,
xyz: &'life1 Xyz,
data: Vec<u8>,
) -> Pin<Box<dyn Future<Output = Result<(), TileStoreError>> + Send + 'async_trait>>
where Self: 'async_trait,
'life0: 'async_trait,
'life1: 'async_trait;
// Provided methods
fn put_tile_mut<'life0, 'life1, 'async_trait>(
&'life0 mut self,
xyz: &'life1 Xyz,
data: Vec<u8>,
) -> Pin<Box<dyn Future<Output = Result<(), TileStoreError>> + Send + 'async_trait>>
where Self: 'async_trait,
'life0: 'async_trait,
'life1: 'async_trait { ... }
fn put_tiles<'life0, 'life1, 'async_trait>(
&'life0 mut self,
tiles: &'life1 [(u8, u32, u32, Vec<u8>)],
) -> Pin<Box<dyn Future<Output = Result<(), TileStoreError>> + Send + 'async_trait>>
where Self: 'async_trait,
'life0: 'async_trait,
'life1: 'async_trait { ... }
fn finalize(&mut self) -> Result<(), TileStoreError> { ... }
}Required Methods
Sourcefn compression(&self) -> Compression
fn compression(&self) -> Compression
Tile storage compression
Sourcefn exists<'life0, 'life1, 'async_trait>(
&'life0 self,
xyz: &'life1 Xyz,
) -> Pin<Box<dyn Future<Output = bool> + Send + 'async_trait>>where
Self: 'async_trait,
'life0: 'async_trait,
'life1: 'async_trait,
fn exists<'life0, 'life1, 'async_trait>(
&'life0 self,
xyz: &'life1 Xyz,
) -> Pin<Box<dyn Future<Output = bool> + Send + 'async_trait>>where
Self: 'async_trait,
'life0: 'async_trait,
'life1: 'async_trait,
Check for existing tile Must not be implemented for cases where generating a tile is less expensive than checking
Provided Methods
Sourcefn put_tile_mut<'life0, 'life1, 'async_trait>(
&'life0 mut self,
xyz: &'life1 Xyz,
data: Vec<u8>,
) -> Pin<Box<dyn Future<Output = Result<(), TileStoreError>> + Send + 'async_trait>>where
Self: 'async_trait,
'life0: 'async_trait,
'life1: 'async_trait,
fn put_tile_mut<'life0, 'life1, 'async_trait>(
&'life0 mut self,
xyz: &'life1 Xyz,
data: Vec<u8>,
) -> Pin<Box<dyn Future<Output = Result<(), TileStoreError>> + Send + 'async_trait>>where
Self: 'async_trait,
'life0: 'async_trait,
'life1: 'async_trait,
Write tile into store requiring &mut self
Sourcefn put_tiles<'life0, 'life1, 'async_trait>(
&'life0 mut self,
tiles: &'life1 [(u8, u32, u32, Vec<u8>)],
) -> Pin<Box<dyn Future<Output = Result<(), TileStoreError>> + Send + 'async_trait>>where
Self: 'async_trait,
'life0: 'async_trait,
'life1: 'async_trait,
fn put_tiles<'life0, 'life1, 'async_trait>(
&'life0 mut self,
tiles: &'life1 [(u8, u32, u32, Vec<u8>)],
) -> Pin<Box<dyn Future<Output = Result<(), TileStoreError>> + Send + 'async_trait>>where
Self: 'async_trait,
'life0: 'async_trait,
'life1: 'async_trait,
Write multiple tiles into store
Sourcefn finalize(&mut self) -> Result<(), TileStoreError>
fn finalize(&mut self) -> Result<(), TileStoreError>
Finalize writing